#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-streams
version:              0.8.9.9
visibility:           public
id:                   http-streams-0.8.9.9-C6emenz6WLRT8GIHkJ48T
key:                  http-streams-0.8.9.9-C6emenz6WLRT8GIHkJ48T
license:              BSD-3-Clause
copyright:            © 2012-2023 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-streams/
synopsis:             An HTTP client using io-streams
description:
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    handle the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  4e456ecb28a5d4dbfee22098a16b31a6
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-streams
hs-libraries:         HShttp-streams-0.8.9.9-C6emenz6WLRT8GIHkJ48T
depends:
    HsOpenSSL-0.11.7.9-LBtSxZW2rmK2S2GXK28cSX
    aeson-2.2.1.0-LCgCxr5fZ2fF779OJkJoWg
    attoparsec-0.14.4-5VjG494kZnAHtf5YQc6bBX
    attoparsec-aeson-2.2.0.0-DiU0AgMNLFq3KpEfWdeQXJ base-4.18.2.1
    base64-bytestring-1.2.1.0-HLeUqWui6e44MugpsqaBEq
    blaze-builder-0.4.4.1-LiAxu3bymWABtV7SInnQkw bytestring-0.11.5.3
    case-insensitive-1.2.1.0-8jGUMPhZyRG9nNczCrjpjo directory-1.3.8.5
    filepath-1.4.300.1 http-common-0.8.3.4-BwSjsgbM9kpA6k9fUfh1yt
    io-streams-1.5.2.2-5agzf72lT9P5pjpJkk7Mur mtl-2.3.1
    network-3.1.4.0-6AYqb02akSc9hPJrZzNJ51
    network-uri-2.6.4.2-6zqYHFTN4FAKhZiyZc7uW4
    openssl-streams-1.2.3.0-GVaLYdEhX1KDBGBikBhOp8 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-LFprVvrjTX4JVFniJRp7e6

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

